@@ -231,7 +231,7 @@ void FcitxKeyLabelWidget::setShortcutShow(bool flag)
             label->show();
         }
         setMaximumWidth(w);
-
+        setFocus();
     } else {
         for (FcitxKeyLabel *label : m_list) {
             label->hide();
@@ -242,13 +242,14 @@ void FcitxKeyLabelWidget::setShortcutShow(bool flag)
         m_keyEdit->clear();
         setMaximumWidth(9999);
     }
-    update();
+    //update();
 }
 
 bool FcitxKeyLabelWidget::checkNewKey(bool isRelease)
 {
     QStringList list {publisherFunc::getKeyValue(Qt::Key_Control),
                       publisherFunc::getKeyValue(Qt::Key_Alt),
+                      publisherFunc::getKeyValue(Qt::Key_Shift),
                       publisherFunc::getKeyValue(Qt::Key_Super_L)};
 
     if (m_newlist.count() == 2) {
@@ -320,6 +321,8 @@ FcitxKeySettingsItem::FcitxKeySettingsItem(const QString &text, const QStringLis
     setFixedHeight(48);
     setAccessibleName(text);
     setLayout(m_hLayout);
+    setTabOrder(m_keyWidget, m_label);
+    m_label->setFocusPolicy(Qt::TabFocus);
     connect(m_keyWidget, &FcitxKeyLabelWidget::editedFinish, this, &FcitxKeySettingsItem::editedFinish);
     connect(m_keyWidget, &FcitxKeyLabelWidget::shortCutError, this, &FcitxKeySettingsItem::doShortCutError);
 }
@@ -432,6 +435,7 @@ FcitxHotKeySettingsItem::FcitxHotKeySettingsItem(const QString &text, const QStr
     setFixedHeight(48);
     setAccessibleName(text);
     setLayout(m_hLayout);
+    setTabOrder(m_keyWidget, m_label);
     connect(m_keyWidget, &FcitxKeyLabelWidget::editedFinish, this, &FcitxHotKeySettingsItem::editedFinish);
     connect(m_keyWidget, &FcitxKeyLabelWidget::shortCutError, this, &FcitxHotKeySettingsItem::doShortCutError);
 }
@@ -568,9 +572,10 @@ FcitxCheckBoxSettingsItem::FcitxCheckBoxSettingsItem(FcitxAddon *addon, QWidget
         if (fp) {
             fprintf(fp, "[Addon]\nEnabled=%s\n", addon->bEnabled ? "True" : "False");
             fclose(fp);
-            if(Fcitx::Global::instance()->inputMethodProxy() != nullptr) {
-                Fcitx::Global::instance()->inputMethodProxy()->ReloadConfig();
-            }
+//            if(Fcitx::Global::instance()->inputMethodProxy() != nullptr) {
+//                Fcitx::Global::instance()->inputMethodProxy()->ReloadConfig();
+//            }
+            emit onChecked();
         }
     });
 
@@ -698,7 +703,7 @@ void FcitxGlobalSettingsItem::paintEvent(QPaintEvent *event)
     const int radius = 8;
     QRect paintRect = this->rect();
     QPainterPath path;
-    if(m_index == firstItem || m_index == onlyoneItem) {
+    if(m_index == firstItem) {
         path.moveTo(paintRect.bottomRight());
         path.lineTo(paintRect.topRight() + QPoint(0, radius));
         path.arcTo(QRect(QPoint(paintRect.topRight() - QPoint(radius * 2, 0)),
@@ -707,7 +712,7 @@ void FcitxGlobalSettingsItem::paintEvent(QPaintEvent *event)
         path.arcTo(QRect(QPoint(paintRect.topLeft()), QSize(radius * 2, radius * 2)), 90, 90);
         path.lineTo(paintRect.bottomLeft());
         path.lineTo(paintRect.bottomRight());
-    } if(m_index == lastItem || m_index == onlyoneItem) {
+    } if(m_index == lastItem) {
         path.moveTo(paintRect.bottomRight() - QPoint(0, radius));
         path.lineTo(paintRect.topRight());
         path.lineTo(paintRect.topLeft());
