@@ -2,31 +2,31 @@
 namespace dcc_fcitx_configtool {
 namespace widgets {
 
-Fcitx_ShortenLabel::Fcitx_ShortenLabel(const QString &text, QWidget *parent)
+FcitxShortenLabel::FcitxShortenLabel(const QString &text, QWidget *parent)
     : m_text(text)
     , QLabel(text, parent)
 {
 }
 
-void Fcitx_ShortenLabel::setShortenText(const QString &text)
+void FcitxShortenLabel::setShortenText(const QString &text)
 {
     m_text = text;
     setText(m_text);
     updateTitleSize();
 }
 
-QString Fcitx_ShortenLabel::text() const
+QString FcitxShortenLabel::text() const
 {
     return m_text;
 }
 
-void Fcitx_ShortenLabel::resizeEvent(QResizeEvent *event)
+void FcitxShortenLabel::resizeEvent(QResizeEvent *event)
 {
     updateTitleSize();
     QLabel::resizeEvent(event);
 }
 
-void Fcitx_ShortenLabel::updateTitleSize()
+void FcitxShortenLabel::updateTitleSize()
 {
     QFontMetrics fontMetrics(font());
     int fontSize = fontMetrics.width(m_text); //获取之前设置的字符串的像素大小
