@@ -62,16 +62,14 @@
 #include "settingsdef.h"
 #include "gsettingwatcher.h"
 
-#define RoundColor(c) ((c)>=0?((c)<=255?c:255):0)
 DWIDGET_USE_NAMESPACE
-namespace Fcitx
-{
+namespace Fcitx {
 
-static void SyncFilterFunc(FcitxGenericConfig* gconfig, FcitxConfigGroup *group, FcitxConfigOption *option, void *value, FcitxConfigSync sync, void *arg);
+static void SyncFilterFunc(FcitxGenericConfig *gconfig, FcitxConfigGroup *group, FcitxConfigOption *option, void *value, FcitxConfigSync sync, void *arg);
 
 const UT_icd addonicd = {sizeof(FcitxAddon), nullptr, nullptr, FcitxAddonFree};
 
-AdvancedSettingWidget::AdvancedSettingWidget(QWidget* parent)
+AdvancedSettingWidget::AdvancedSettingWidget(QWidget *parent)
     : QWidget(parent)
     , m_hash(new QHash<QString, FcitxConfigFileDesc *>)
     , m_prefix("")
@@ -81,18 +79,19 @@ AdvancedSettingWidget::AdvancedSettingWidget(QWidget* parent)
     , m_addOnsLayout(new QVBoxLayout)
     , m_simpleUiType(CW_NoShow)
     , m_fullUiType(CW_NoShow)
+    , m_gsetting(new QGSettings("com.deepin.fcitx-config", QByteArray(), this))
 {
     getConfigDesc("config.desc");
     setupConfigUi();
-    connect(Global::instance()->inputMethodProxy(), &FcitxQtInputMethodProxy::ReloadConfigUI, this, [=](){
-        if (m_config && (!m_isSelfSend)) {
+    connect(Global::instance()->inputMethodProxy(), &FcitxQtInputMethodProxy::ReloadConfigUI, this, [ & ]() {
+        if (m_config.isValid() && (!m_isSelfSend)) {
             FILE *fp;
             fp = FcitxXDGGetFileWithPrefix(m_prefix.toLocal8Bit().constData(), m_name.toLocal8Bit().constData(), "r", nullptr);
-            if (!fp) {
-                return;
+            if (fp) {
+                m_config.load(fp);
+                m_config.configSyncToUi();
+                fclose(fp);
             }
-            m_config->load(fp);
-            m_config->sync();
         }
     });
     connect(DGuiApplicationHelper::instance(), &DGuiApplicationHelper::themeTypeChanged, this, &AdvancedSettingWidget::onPalettetypechanged);
@@ -119,7 +118,7 @@ void AdvancedSettingWidget::setupConfigUi()
     pTopSwitchWidgetBtn->setId(btnAddOns, 1);
     pTopSwitchWidgetBtn->setMinimumSize(240, 36);
 
-    QVBoxLayout* layout = new QVBoxLayout(this);
+    QVBoxLayout *layout = new QVBoxLayout(this);
     layout->setContentsMargins(0, 0, 0, 0);
     layout->addWidget(pTopSwitchWidgetBtn,  0, Qt::AlignHCenter);
     QStackedLayout *stackLayout = new QStackedLayout;
@@ -132,11 +131,12 @@ void AdvancedSettingWidget::setupConfigUi()
     addOnsWidget->setLayout(m_addOnsLayout);
     stackLayout->addWidget(globalSettingsWidget);
     stackLayout->addWidget(addOnsWidget);
+    layout->addSpacing(10);
     layout->addLayout(stackLayout);
-    connect(btnGlobalSettings, &DButtonBoxButton::clicked, this, [=](){
+    connect(btnGlobalSettings, &DButtonBoxButton::clicked, this, [ = ]() {
         stackLayout->setCurrentIndex(0);
     });
-    connect(btnAddOns, &DButtonBoxButton::clicked, this, [=](){
+    connect(btnAddOns, &DButtonBoxButton::clicked, this, [ = ]() {
         stackLayout->setCurrentIndex(1);
     });
     setLayout(layout);
@@ -146,84 +146,225 @@ void AdvancedSettingWidget::setupConfigUi()
         bind_textdomain_codeset(m_cfdesc->domain, "UTF-8");
         FILE *fp;
         fp = FcitxXDGGetFileWithPrefix(m_prefix.toLocal8Bit().constData(), m_name.toLocal8Bit().constData(), "r", nullptr);
-        m_config->load(fp);
-
-        if (fp)
+        if (fp) {
+            m_config.load(fp);
             fclose(fp);
+        }
     }
     m_globalSettingsLayout->setContentsMargins(0, 0, 0, 0);
     m_addOnsLayout->setContentsMargins(0, 0, 0, 0);
     m_globalSettingsLayout->addWidget(createglobalSettingsUi());
     m_addOnsLayout->addWidget(createAddOnsUi());
 
-    if (m_config) {
-        m_config->sync();
+    if (m_config.isValid()) {
+        m_config.configSyncToUi();
     }
 }
 
 AdvancedSettingWidget::~AdvancedSettingWidget()
 {
-    if (m_config)
-        delete m_config;
 }
 
-void AdvancedSettingWidget::createConfigOptionWidget(FcitxConfigGroupDesc* cgdesc, FcitxConfigOptionDesc* codesc, QString& label,
-                                                     QString& tooltip, QWidget*& inputWidget, void*& newarg)
+QWidget *AdvancedSettingWidget::createglobalSettingsUi()
 {
-    FcitxConfigOptionDesc2* codesc2 = (FcitxConfigOptionDesc2*) codesc;
+    int row = 0;
+    VerticalScrollArea *scrollarea = new VerticalScrollArea;
+    scrollarea->setFrameStyle(QFrame::NoFrame);
+    scrollarea->setWidgetResizable(true);
+
+    QWidget *form = new QWidget;
+    QVBoxLayout *vgLayout = new QVBoxLayout;
+    vgLayout->setContentsMargins(20, 0, 20, 0);
+    scrollarea->setWidget(form);
+    form->setLayout(vgLayout);
+
+    do {
+        if (!m_cfdesc)
+            break;
+
+        if (!m_config.isValid())
+            break;
+
+        HASH_FOREACH(cgdesc, m_cfdesc->groupsDesc, FcitxConfigGroupDesc) {
+            ArrowButton *grouplabel = new ArrowButton();
+            grouplabel->setText(QString("%1").arg(QString::fromUtf8(dgettext(m_cfdesc->domain, cgdesc->groupName))));
+            grouplabel->setAccessibleName(cgdesc->groupName);
+            QFont f;
+            f.setPixelSize(17);
+            f.setWeight(QFont::DemiBold);
+            grouplabel->setFont(f);
+            ArrowButton *button = new ArrowButton();
+            QPixmap pmap = QIcon::fromTheme("dm_arrow").pixmap(QSize(12, 8));
+            button->setPixmap(pmap);
+            button->setMaximumWidth(30);
+            QHBoxLayout *hglayout = new QHBoxLayout;
+
+
+            hglayout->addSpacing(10);
+            hglayout->addWidget(grouplabel);
+            hglayout->addWidget(button, Qt::AlignRight);
+            vgLayout->addLayout(hglayout);
+            QWidget *content = new QWidget;
+            QSizePolicy policy;
+            policy.setVerticalPolicy(QSizePolicy::Fixed);
+            policy.setHorizontalPolicy(QSizePolicy::Expanding);
+            content->setSizePolicy(policy);
+            QVBoxLayout *vlayout = new QVBoxLayout;
+            vlayout->setContentsMargins(0, 0, 0, 0);
+            content->setLayout(vlayout);
+            //content->setHidden(true);
+            connect(grouplabel, &ArrowButton::pressed, this, [ = ](bool isHidden) {
+                content->setHidden(isHidden);
+                button->setContentHidden(!isHidden);
+                QMatrix matrix;
+                if (isHidden) {
+                    matrix.rotate(180);
+                } else {
+                    matrix.rotate(0);
+                }
+                button->setPixmap(pmap.transformed(matrix, Qt::SmoothTransformation));
+            });
+            connect(button, &ArrowButton::pressed, this, [ = ](bool isHidden) {
+                content->setHidden(isHidden);
+                grouplabel->setContentHidden(!isHidden);
+                QMatrix matrix;
+                if (isHidden) {
+                    matrix.rotate(180);
+                } else {
+                    matrix.rotate(0);
+                }
+                button->setPixmap(pmap.transformed(matrix, Qt::SmoothTransformation));
+            });
+            vgLayout->addWidget(content, Qt::AlignLeft);
+            vgLayout->addSpacing(7);
+            QList<FcitxGlobalSettingsItem *> itemList;
+            HASH_FOREACH(codesc, cgdesc->optionsDesc, FcitxConfigOptionDesc) {
+                QString s, tooltip;
+                QWidget *inputWidget = nullptr;
+                void *argument = nullptr;
+                FcitxConfigOptionDesc2 *codesc2 = (FcitxConfigOptionDesc2 *) codesc;
+                boolean shownInDeepin = codesc2->shownInDeepin;
+                if (shownInDeepin) {
+                    createConfigOptionWidget(cgdesc, codesc, s, tooltip, inputWidget, argument);
+                }
+                if (inputWidget) {
+                    ArrowButton *label = new ArrowButton;
+                    label->setOriginText(s);
+                    QFont f;
+                    f.setPixelSize(13);
+                    //f.setWeight(QFont::DemiBold);
+                    label->setFont(f);
+                    label->setMinimumWidth(100);
+                    if (!tooltip.isEmpty()) {
+                        label->setToolTip(tooltip);
+                    }
+                    FcitxGlobalSettingsItem *pitem = new FcitxGlobalSettingsItem;
+                    itemList.append(pitem);
+                    pitem->setMinimumWidth(100);
+                    QHBoxLayout *hlayout = new QHBoxLayout;
+                    if (codesc->type == T_Hotkey) {
+                        pitem->setMaximumHeight(46);
+                        label->setAlignment(Qt::AlignVCenter);
+                        hlayout->setContentsMargins(10, 0, 0, 10);
+                    } else {
+                        hlayout->setContentsMargins(10, 5, 5, 10);
+                    }
+                    hlayout->addWidget(label);
+                    hlayout->addWidget(inputWidget, Qt::AlignCenter);
+                    pitem->setLayout(hlayout);
+                    vlayout->addWidget(pitem);
+                    vlayout->addSpacing(-5);
+                    if (argument) {
+                        m_config.bind(cgdesc->groupName, codesc->optionName, SyncFilterFunc, argument);
+                    }
+                    row++;
+                }
+            }
+            if(!itemList.isEmpty()) {
+                itemList.first()->setIndex(0);
+                itemList.last()->setIndex(-1);
+            }
+            if (QString(cgdesc->groupName) == "Hotkey") {
+                bindGsettings(GSETTINGS_GLOBALCONFIG_SHORTCUT, hglayout);
+                bindGsettings(GSETTINGS_GLOBALCONFIG_SHORTCUT, content);
+            } else if (QString(cgdesc->groupName) == "Program") {
+                bindGsettings(GSETTINGS_GLOBALCONFIG_PROGRAM, hglayout);
+                bindGsettings(GSETTINGS_GLOBALCONFIG_PROGRAM, content);
+            } else if (QString(cgdesc->groupName) == "Output") {
+                bindGsettings(GSETTINGS_GLOBALCONFIG_OUTPUT, hglayout);
+                bindGsettings(GSETTINGS_GLOBALCONFIG_OUTPUT, content);
+            } else if (QString(cgdesc->groupName) == "Appearance") {
+                bindGsettings(GSETTINGS_GLOBALCONFIG_APPEARANCE, hglayout);
+                bindGsettings(GSETTINGS_GLOBALCONFIG_APPEARANCE, content);
+            }
+        }
+    } while (0);
+
+
+    //QSpacerItem* verticalSpacer = new QSpacerItem(20, 10);
+
+//    if (row >= 2) {
+//        QSpacerItem* horizontalSpacer = new QSpacerItem(20, 20, QSizePolicy::Fixed, QSizePolicy::Minimum);
+//        vgLayout->addItem(horizontalSpacer);
+//    }
+
+    vgLayout->addSpacing(10);
+    vgLayout->addStretch();
+    bindGsettings(GSETTINGS_ADVANCESETTING_GLOBALCONFIG, form);
+    return scrollarea;
+}
+
+void AdvancedSettingWidget::createConfigOptionWidget(FcitxConfigGroupDesc *cgdesc, FcitxConfigOptionDesc *codesc, QString &label,
+                                                     QString &tooltip, QWidget *&inputWidget, void *&newarg)
+{
+    FcitxConfigOptionDesc2 *codesc2 = (FcitxConfigOptionDesc2 *) codesc;
 
-    void* oldarg = nullptr;
-    void* argument = nullptr;
-    QString strrrr = codesc->shownInDeepin;
     QString name(QString("%1/%2").arg(cgdesc->groupName).arg(codesc->optionName));
     if (m_argsMap.contains(name)) {
-        oldarg = m_argsMap[name];
     }
 
-    if (codesc->desc && codesc->desc[0])
+    if (codesc->desc && codesc->desc[0]) {
         label = QString::fromUtf8(dgettext(m_cfdesc->domain, codesc->desc));
-    else
+    } else {
         label = QString::fromUtf8(dgettext(m_cfdesc->domain, codesc->optionName));
-
+    }
     if (codesc2->longDesc && codesc2->longDesc[0]) {
         tooltip = QString::fromUtf8(dgettext(m_cfdesc->domain, codesc2->longDesc));
     }
 
     switch (codesc->type) {
-
     case T_Integer: {
-        DSpinBox* spinbox = new DSpinBox(this);
+        DSpinBox *spinbox = new DSpinBox(this);
         spinbox->setAccessibleName(name.split('/').last());
         spinbox->setEnabledEmbedStyle(true);
         spinbox->setMinimumWidth(50);
+        spinbox->setMaximumHeight(48);
         spinbox->setMaximum(codesc2->constrain.integerConstrain.max);
         spinbox->setMinimum(codesc2->constrain.integerConstrain.min);
         inputWidget = spinbox;
-        connect(spinbox,  QOverload<int>::of(&DSpinBox::valueChanged), this, [=](int value) {
+        connect(spinbox,  QOverload<int>::of(&DSpinBox::valueChanged), this, [ = ](int value) {
             IMConfig::setIMvalue(codesc->optionName, QString().number(value));
             sendReloadMessage();
         });
         break;
     }
-
     case T_Boolean: {
         DSwitchButton *pSwitchBtn = new DSwitchButton;
         pSwitchBtn->setAccessibleName(name.split('/').last());
-        if(QString(codesc->rawDefaultValue).contains("True")) {
-           pSwitchBtn->setChecked(true);
+        if (QString(codesc->rawDefaultValue).contains("True")) {
+            pSwitchBtn->setChecked(true);
         }
         inputWidget = pSwitchBtn;
-        connect(pSwitchBtn, &DSwitchButton::clicked, this, [=](bool checked) {
+        connect(pSwitchBtn, &DSwitchButton::clicked, this, [ = ](bool checked) {
             IMConfig::setIMvalue(codesc->optionName, checked ? "True" : "False");
             sendReloadMessage();
         });
         break;
     }
-
     case T_Enum: {
         int i;
         FcitxConfigEnum *e = &codesc->configEnum;
-        QComboBox* combobox = new QComboBox(this);
+        QComboBox *combobox = new QComboBox(this);
         combobox->setAccessibleName(name.split('/').last());
         combobox->setMinimumWidth(150);
         combobox->setMaximumHeight(48);
@@ -233,22 +374,20 @@ void AdvancedSettingWidget::createConfigOptionWidget(FcitxConfigGroupDesc* cgdes
             combobox->addItem(QString::fromUtf8(dgettext(m_cfdesc->domain, e->enumDesc[i])));
             combobox->setItemData(i, e->enumDesc[i]);
         }
-        connect(combobox, &QComboBox::currentTextChanged, this, [=](const QString& text) {
+        connect(combobox, &QComboBox::currentTextChanged, this, [ = ](const QString & text) {
             int index = combobox->findText(text);
             IMConfig::setIMvalue(codesc->optionName, combobox->itemData(index).toString());
             sendReloadMessage();
         });
+        break;
     }
-
-    break;
-
     case T_Hotkey: {
-        FcitxHotKeySettingsItem* item = new FcitxHotKeySettingsItem;
+        FcitxHotKeySettingsItem *item = new FcitxHotKeySettingsItem;
         item->setAccessibleName(name.split('/').last());
         item->setMaximumWidth(150);
         item->enableSingleKey();
         item->setList(QString(codesc->rawDefaultValue).split(' ').first().split('_'));
-        if(QString(codesc->rawDefaultValue).isEmpty()) {
+        if (QString(codesc->rawDefaultValue).isEmpty()) {
             item->setList(QString(tr("None")).split('_'));
         }
         inputWidget = item;
@@ -258,28 +397,21 @@ void AdvancedSettingWidget::createConfigOptionWidget(FcitxConfigGroupDesc* cgdes
             item->setList(item->getKeyToStr().split("_"));
             sendReloadMessage();
         });
+        break;
     };
-
-    break;
-
     case T_Char:
-
     case T_String: {
-        QLineEdit* lineEdit = new QLineEdit(this);
+        QLineEdit *lineEdit = new QLineEdit(this);
         lineEdit->setMinimumWidth(150);
         inputWidget = lineEdit;
-        argument = inputWidget;
         connect(lineEdit, &QLineEdit::editingFinished, [ = ]() {
             IMConfig::setIMvalue(codesc->optionName, lineEdit->text());
             sendReloadMessage();
         });
+        break;
     }
-
-    break;
-
     case T_I18NString:
         inputWidget = nullptr;
-        argument = nullptr;
         break;
     default:
         break;
@@ -295,206 +427,6 @@ void AdvancedSettingWidget::createConfigOptionWidget(FcitxConfigGroupDesc* cgdes
     }
 }
 
-QWidget* AdvancedSettingWidget::createglobalSettingsUi()
-{
-    int row = 0;
-    VerticalScrollArea *scrollarea = new VerticalScrollArea;
-    scrollarea->setFrameStyle(QFrame::NoFrame);
-    scrollarea->setWidgetResizable(true);
-
-    QWidget* form = new QWidget;
-    QVBoxLayout* vgLayout = new QVBoxLayout;
-    vgLayout->setContentsMargins(20, 0, 20, 0);
-    scrollarea->setWidget(form);
-    form->setLayout(vgLayout);
-
-    do {
-        if (!m_cfdesc)
-            break;
-
-        if (!m_config->isValid())
-            break;
-
-        HASH_FOREACH(cgdesc, m_cfdesc->groupsDesc, FcitxConfigGroupDesc) {
-            arrowButton* grouplabel = new arrowButton();
-            grouplabel->setText(QString("%1").arg(QString::fromUtf8(dgettext(m_cfdesc->domain, cgdesc->groupName))));
-            grouplabel->setAccessibleName(cgdesc->groupName);
-            QFont f;
-            f.setPixelSize(17);
-            f.setWeight(QFont::DemiBold);
-            grouplabel->setFont(f);
-            arrowButton *button =new arrowButton();
-            QPixmap pmap = QIcon::fromTheme("dm_arrow").pixmap(QSize(12, 8));
-            button->setPixmap(pmap);
-            button->setMaximumWidth(30);
-            QHBoxLayout *hglayout = new QHBoxLayout;
-            QGSettings *gsetting = new QGSettings("com.deepin.fcitx-config", QByteArray(), this);
-            if(QString(cgdesc->groupName) == "Hotkey") {
-                QString value = gsetting->get(GSETTINGS_GLOBALCONFIG_SHORTCUT).toString();
-                if ("Enabled" == value) {
-                    grouplabel->setEnabled(true);
-                    button->setEnabled(true);
-                } else if ("Disabled" == value) {
-                    grouplabel->setEnabled(false);
-                    button->setEnabled(false);
-                }
-                grouplabel->setVisible("Hidden" != value);
-                button->setVisible("Hidden" != value);
-
-                GSettingWatcher::instance()->bind(GSETTINGS_GLOBALCONFIG_SHORTCUT, grouplabel);
-                GSettingWatcher::instance()->bind(GSETTINGS_GLOBALCONFIG_SHORTCUT, button);
-            } else if(QString(cgdesc->groupName) == "Program") {
-                QString value = gsetting->get(GSETTINGS_GLOBALCONFIG_PROGRAM).toString();
-                if ("Enabled" == value) {
-                    grouplabel->setEnabled(true);
-                    button->setEnabled(true);
-                } else if ("Disabled" == value) {
-                    grouplabel->setEnabled(false);
-                    button->setEnabled(false);
-                }
-                grouplabel->setVisible("Hidden" != value);
-                button->setVisible("Hidden" != value);
-
-                GSettingWatcher::instance()->bind(GSETTINGS_GLOBALCONFIG_PROGRAM, grouplabel);
-                GSettingWatcher::instance()->bind(GSETTINGS_GLOBALCONFIG_PROGRAM, button);
-            } else if(QString(cgdesc->groupName) == "Output") {
-                QString value = gsetting->get(GSETTINGS_GLOBALCONFIG_OUTPUT).toString();
-                if ("Enabled" == value) {
-                    grouplabel->setEnabled(true);
-                    button->setEnabled(true);
-                } else if ("Disabled" == value) {
-                    grouplabel->setEnabled(false);
-                    button->setEnabled(false);
-                }
-                grouplabel->setVisible("Hidden" != value);
-                button->setVisible("Hidden" != value);
-
-                GSettingWatcher::instance()->bind(GSETTINGS_GLOBALCONFIG_OUTPUT, grouplabel);
-                GSettingWatcher::instance()->bind(GSETTINGS_GLOBALCONFIG_OUTPUT, button);
-            } else if(QString(cgdesc->groupName) == "Appearance") {
-                QString value = gsetting->get(GSETTINGS_GLOBALCONFIG_APPEARANCE).toString();
-                if ("Enabled" == value) {
-                    grouplabel->setEnabled(true);
-                    button->setEnabled(true);
-                } else if ("Disabled" == value) {
-                    grouplabel->setEnabled(false);
-                    button->setEnabled(false);
-                }
-                grouplabel->setVisible("Hidden" != value);
-                button->setVisible("Hidden" != value);
-
-                GSettingWatcher::instance()->bind(GSETTINGS_GLOBALCONFIG_APPEARANCE, grouplabel);
-                GSettingWatcher::instance()->bind(GSETTINGS_GLOBALCONFIG_APPEARANCE, button);
-            }
-            QString value = gsetting->get(GSETTINGS_ADVANCESETTING_GLOBALCONFIG).toString();
-            if ("Enabled" == value) {
-                grouplabel->setEnabled(true);
-                button->setEnabled(true);
-            } else if ("Disabled" == value) {
-                grouplabel->setEnabled(false);
-                button->setEnabled(false);
-            }
-            grouplabel->setVisible("Hidden" != value);
-            button->setVisible("Hidden" != value);
-            GSettingWatcher::instance()->bind(GSETTINGS_ADVANCESETTING_GLOBALCONFIG, grouplabel);
-            GSettingWatcher::instance()->bind(GSETTINGS_ADVANCESETTING_GLOBALCONFIG, button);
-
-            hglayout->addSpacing(10);
-            hglayout->addWidget(grouplabel);
-            hglayout->addWidget(button, Qt::AlignRight);
-            vgLayout->addLayout(hglayout);
-            QWidget *content = new QWidget;
-            QSizePolicy policy;
-            policy.setVerticalPolicy(QSizePolicy::Fixed);
-            policy.setHorizontalPolicy(QSizePolicy::Expanding);
-            content->setSizePolicy(policy);
-            QVBoxLayout *vlayout = new QVBoxLayout;
-            vlayout->setContentsMargins(0, 0, 0, 0);
-            content->setLayout(vlayout);
-            content->setHidden(true);
-            connect(grouplabel, &arrowButton::pressed, this, [=](bool isHidden) {
-                content->setHidden(isHidden);
-                button->setContentHidden(!isHidden);
-                QMatrix matrix;
-                if(!isHidden) {
-                    matrix.rotate(180);
-                } else {
-                    matrix.rotate(0);
-                }
-                button->setPixmap(pmap.transformed(matrix, Qt::SmoothTransformation));
-            });
-            connect(button, &arrowButton::pressed, this, [=](bool isHidden) {
-                content->setHidden(isHidden);
-                grouplabel->setContentHidden(!isHidden);
-                QMatrix matrix;
-                if(!isHidden) {
-                    matrix.rotate(180);
-                } else {
-                    matrix.rotate(0);
-                }
-                button->setPixmap(pmap.transformed(matrix, Qt::SmoothTransformation));
-            });
-            vgLayout->addWidget(content, Qt::AlignLeft);
-            vgLayout->addSpacing(7);
-            QList<FcitxGlobalSettingsItem*> itemList;
-            HASH_FOREACH(codesc, cgdesc->optionsDesc, FcitxConfigOptionDesc) {
-                QString s, tooltip;
-                QWidget* inputWidget = nullptr;
-                void* argument = nullptr;
-                QString shownInDeepin = codesc->shownInDeepin;
-                if(shownInDeepin.contains("True")) {
-                    createConfigOptionWidget(cgdesc, codesc, s, tooltip, inputWidget, argument);
-                }
-                if (inputWidget) {
-                    arrowButton* label = new arrowButton;
-                    label->setOriginText(s);
-                    QFont f;
-                    f.setPixelSize(13);
-                    //f.setWeight(QFont::DemiBold);
-                    label->setFont(f);
-                    label->setMinimumWidth(100);
-                    if (!tooltip.isEmpty()) {
-                        label->setToolTip(tooltip);
-                    }
-                    FcitxGlobalSettingsItem *pitem = new FcitxGlobalSettingsItem;
-                    itemList.append(pitem);
-                    pitem->setMinimumWidth(100);
-                    pitem->setMaximumHeight(46);
-                    QHBoxLayout *hlayout = new QHBoxLayout;
-                    if(codesc->type == T_Hotkey) {
-                        label->setAlignment( Qt::AlignBottom);
-                        hlayout->setContentsMargins(10, 0, 0, 10);
-                    } else {
-                        hlayout->setContentsMargins(10, 5, 5, 10);
-                    }
-                    hlayout->addWidget(label);
-                    hlayout->addWidget(inputWidget, Qt::AlignCenter);
-                    pitem->setLayout(hlayout);
-                    vlayout->addWidget(pitem);
-                    vlayout->addSpacing(-5);
-                    if (argument) {
-                        m_config->bind(cgdesc->groupName, codesc->optionName, SyncFilterFunc, argument);
-                    }
-                    row++;
-                }
-            }
-            itemList.first()->setIndex(0);
-            itemList.last()->setIndex(-1);
-        }
-    } while(0);
-
-
-    //QSpacerItem* verticalSpacer = new QSpacerItem(20, 10);
-
-//    if (row >= 2) {
-//        QSpacerItem* horizontalSpacer = new QSpacerItem(20, 20, QSizePolicy::Fixed, QSizePolicy::Minimum);
-//        vgLayout->addItem(horizontalSpacer);
-//    }
-
-    vgLayout->addSpacing(10);
-    vgLayout->addStretch();
-    return scrollarea;
-}
 
 QWidget *AdvancedSettingWidget::createAddOnsUi()
 {
@@ -514,13 +446,26 @@ QWidget *AdvancedSettingWidget::createAddOnsUi()
         utarray_new(m_addons, &addonicd);
         FcitxAddonsLoad(m_addons);
         if (m_addons) {
-            for (FcitxAddon* addon = (FcitxAddon *) utarray_front(m_addons);
+            for (FcitxAddon *addon = (FcitxAddon *) utarray_front(m_addons);
                     addon != nullptr; addon = (FcitxAddon *) utarray_next(m_addons, addon)) {
-                FcitxCheckBoxSettingsItem *item =new FcitxCheckBoxSettingsItem(addon, area);
+                if (addon->advance) {
+                    continue;
+                }
+                FcitxCheckBoxSettingsItem *item = new FcitxCheckBoxSettingsItem(addon, area);
                 item->addBackground();
                 item->setMinimumWidth(200);
                 layout->addWidget(item);
                 layout->addSpacing(5);
+                m_addonsList.append(item);
+                connect(item, &FcitxCheckBoxSettingsItem::onChecked, this, [ = ]() {
+                    QProcess p;
+                    p.startDetached("sh -c \"fcitx -r\"");
+                    p.waitForFinished();
+                        area->setEnabled(false);
+                        QTimer::singleShot(2000, this, [ = ]() {
+                            area->setEnabled(true);
+                        });
+                });
             }
         }
     }
@@ -541,22 +486,56 @@ void AdvancedSettingWidget::getConfigDesc(const QString &name)
         m_cfdesc = (*m_hash)[name];
     }
     if (m_cfdesc) {
-        m_config = new DummyConfig(m_cfdesc);
+        m_config.setConfigDesc(m_cfdesc);
     }
     return;
 }
 
 void AdvancedSettingWidget::sendReloadMessage()
 {
-    if(Global::instance()->inputMethodProxy() != nullptr) {
+    if (Global::instance()->inputMethodProxy() != nullptr) {
         Global::instance()->inputMethodProxy()->ReloadConfig();
     }
     m_isSelfSend = true;
-    QTimer::singleShot(200, this, [=](){
+    QTimer::singleShot(200, this, [ = ]() {
         m_isSelfSend = false;
     });
 }
 
+void AdvancedSettingWidget::bindGsettings(const QString &gsettingsName, QLayout *layout)
+{
+    QString value = m_gsetting->get(gsettingsName).toString();
+
+    for(int i = 0; i < layout->count(); i++) {
+        QWidget *w = layout->itemAt(i)->widget();
+        if(w) {
+            w->setEnabled("Enabled" == value);
+            w->setVisible("Hidden" != value);
+            GSettingWatcher::instance()->bind(gsettingsName, w);
+            continue;
+        }
+        QLayout *lay = layout->itemAt(i)->layout();
+        if(lay) {
+            for(int j = 0; j < lay->count(); j++) {
+                QWidget *ww = lay->itemAt(j)->widget();
+                if(ww) {
+                    ww->setEnabled("Enabled" == value);
+                    ww->setVisible("Hidden" != value);
+                    GSettingWatcher::instance()->bind(gsettingsName, ww);
+                }
+            }
+        }
+    }
+}
+
+void AdvancedSettingWidget::bindGsettings(const QString &gsettingsName, QWidget *w)
+{
+    QString value = m_gsetting->get(gsettingsName).toString();
+    w->setEnabled("Enabled" == value);
+    w->setVisible("Hidden" != value);
+    GSettingWatcher::instance()->bind(gsettingsName, w);
+}
+
 void AdvancedSettingWidget::onPalettetypechanged()
 {
     DPalette p;
@@ -564,7 +543,7 @@ void AdvancedSettingWidget::onPalettetypechanged()
     this->setPalette(p);
 }
 
-void SyncFilterFunc(FcitxGenericConfig* gconfig, FcitxConfigGroup *group, FcitxConfigOption *option,
+void SyncFilterFunc(FcitxGenericConfig *gconfig, FcitxConfigGroup *group, FcitxConfigOption *option,
                     void *value, FcitxConfigSync sync, void *arg)
 {
     Q_UNUSED(gconfig);
@@ -578,64 +557,48 @@ void SyncFilterFunc(FcitxGenericConfig* gconfig, FcitxConfigGroup *group, FcitxC
 
     if (sync == Raw2Value) {
         switch (codesc->type) {
-
         case T_I18NString:
             break;
-
         case T_Integer: {
-            int i = *(int*) value;
-            DSpinBox* spinbox = static_cast<DSpinBox*>(arg);
+            int i = *(int *) value;
+            DSpinBox *spinbox = static_cast<DSpinBox *>(arg);
             spinbox->setValue(i);
+            break;
         }
-
-        break;
-
         case T_Boolean: {
-            boolean *bl = static_cast<boolean*>(value);
-
-            DSwitchButton* checkBox = static_cast<DSwitchButton*>(arg);
-
+            boolean *bl = static_cast<boolean *>(value);
+            DSwitchButton *checkBox = static_cast<DSwitchButton *>(arg);
             checkBox->setChecked(*bl);
+            break;
         }
-
-        break;
-
         case T_Enum: {
-            int index = *(int*) value;
-
-            QComboBox* combobox = static_cast<QComboBox*>(arg);
-
+            int index = *(int *) value;
+            QComboBox *combobox = static_cast<QComboBox *>(arg);
             combobox->setCurrentIndex(index);
+            break;
         }
-
-        break;
-
         case T_Hotkey: {
-            FcitxHotkey* hotkey = static_cast<FcitxHotkey*>(value);
-            FcitxHotKeySettingsItem* item = static_cast<FcitxHotKeySettingsItem*>(arg);
+            FcitxHotkey *hotkey = static_cast<FcitxHotkey *>(value);
+            FcitxHotKeySettingsItem *item = static_cast<FcitxHotKeySettingsItem *>(arg);
             item->setList(QString(hotkey->desc).split("_"));
-            if(QString(hotkey->desc).isEmpty()) {
+            if (QString(hotkey->desc).isEmpty()) {
                 item->setList(QString(QObject::tr("None")).split('_'));
             }
+            break;
         }
-
-        break;
-
         case T_Char: {
-            char* string = static_cast<char*>(value);
+            char *string = static_cast<char *>(value);
             char temp[2] = { *string, '\0' };
-            QLineEdit* lineEdit = static_cast<QLineEdit*>(arg);
+            QLineEdit *lineEdit = static_cast<QLineEdit *>(arg);
             lineEdit->setText(QString::fromUtf8(temp));
+            break;
         }
-        break;
-
         case T_String: {
-            char** string = static_cast<char**>(value);
-            QLineEdit* lineEdit = static_cast<QLineEdit*>(arg);
+            char **string = static_cast<char **>(value);
+            QLineEdit *lineEdit = static_cast<QLineEdit *>(arg);
             lineEdit->setText(QString::fromUtf8(*string));
+            break;
         }
-
-        break;
         default:
             break;
         }
@@ -646,80 +609,72 @@ void SyncFilterFunc(FcitxGenericConfig* gconfig, FcitxConfigGroup *group, FcitxC
         }
 
         switch (codesc->type) {
-
         case T_I18NString:
             break;
-
         case T_Integer: {
-            int* i = static_cast<int*>(value);
-            DSpinBox* spinbox = static_cast<DSpinBox*>(arg);
+            int *i = static_cast<int *>(value);
+            DSpinBox *spinbox = static_cast<DSpinBox *>(arg);
             *i = spinbox->value();
+            break;
         }
-        break;
-
         case T_Boolean: {
-            QCheckBox* checkBox = static_cast<QCheckBox*>(arg);
-            boolean *bl = static_cast<boolean*>(value);
+            QCheckBox *checkBox = static_cast<QCheckBox *>(arg);
+            boolean *bl = static_cast<boolean *>(value);
             *bl = checkBox->isChecked();
+            break;
         }
-        break;
-
         case T_Enum: {
-            QComboBox* combobox = static_cast<QComboBox*>(arg);
-            int* index = static_cast<int*>(value);
+            QComboBox *combobox = static_cast<QComboBox *>(arg);
+            int *index = static_cast<int *>(value);
             *index = combobox->currentIndex();
+            break;
         }
-        break;
-
         case T_Hotkey: {
-            FcitxHotKeySettingsItem* item = static_cast<FcitxHotKeySettingsItem*>(arg);
-            FcitxHotkey* hotkey = static_cast<FcitxHotkey*>(value);
+            FcitxHotKeySettingsItem *item = static_cast<FcitxHotKeySettingsItem *>(arg);
+            FcitxHotkey *hotkey = static_cast<FcitxHotkey *>(value);
             item->setList(QString(hotkey->desc).split("_"));
-            if(QString(codesc->rawDefaultValue).isEmpty()) {
+            if (QString(codesc->rawDefaultValue).isEmpty()) {
                 item->setList(QString(QObject::tr("None")).split('_'));
             }
+            break;
         }
-        break;
-
         case T_Char: {
-            QLineEdit* lineEdit = static_cast<QLineEdit*>(arg);
-            char* c = static_cast<char*>(value);
+            QLineEdit *lineEdit = static_cast<QLineEdit *>(arg);
+            char *c = static_cast<char *>(value);
             *c = lineEdit->text()[0].toLatin1();
+            break;
         }
-        break;
-
         case T_String: {
-            QLineEdit* lineEdit = static_cast<QLineEdit*>(arg);
-            char** string = static_cast<char**>(value);
+            QLineEdit *lineEdit = static_cast<QLineEdit *>(arg);
+            char **string = static_cast<char **>(value);
             fcitx_utils_string_swap(string, lineEdit->text().toUtf8().constData());
+            break;
         }
-        break;
-
         default:
             break;
         }
     }
 }
 
-arrowButton::arrowButton(QWidget *parent)
+ArrowButton::ArrowButton(QWidget *parent)
     : QLabel(parent)
 {
 
 }
 
-void arrowButton::mousePressEvent(QMouseEvent *ev)
+void ArrowButton::mousePressEvent(QMouseEvent *ev)
 {
     Q_UNUSED(ev);
     emit pressed(m_hide);
     m_hide = !m_hide;
 }
 
-void arrowButton::resizeEvent(QResizeEvent *event)
+void ArrowButton::resizeEvent(QResizeEvent *event)
 {
-    if(!m_originText.isEmpty()) {
+    if (!m_originText.isEmpty()) {
         QString name = fontMetrics().elidedText(m_originText, Qt::ElideRight, width());
         setText(name);
-        if(name != m_originText) {
+        if (name != m_originText) {
             setToolTip(m_originText);
         } else {
             setToolTip("");
@@ -728,12 +683,12 @@ void arrowButton::resizeEvent(QResizeEvent *event)
     QLabel::resizeEvent(event);
 }
 
-void arrowButton::setContentHidden(bool hide)
+void ArrowButton::setContentHidden(bool hide)
 {
     m_hide = hide;
 }
 
-void arrowButton::setOriginText(const QString &text)
+void ArrowButton::setOriginText(const QString &text)
 {
     setText(text);
     m_originText = text;
