@@ -73,6 +73,7 @@ void IMAddWindow::initUI()
     hlayout2->addSpacing(10);
     //可用输入法列表
     m_availWidget = new AvailWidget(this);
+    m_availWidget->setAccessibleName("availWidget");
     //应用商店按钮
     QHBoxLayout *hlayout3 = new QHBoxLayout(this);
     hlayout3->addStretch();
@@ -83,9 +84,9 @@ void IMAddWindow::initUI()
     //添加 取消按钮
     m_buttonTuple = new FcitxButtonTuple(FcitxButtonTuple::Save);
     m_buttonTuple->rightButton()->setText(tr("Add"));
-    m_buttonTuple->rightButton()->setAccessibleName(tr("Add"));
+    m_buttonTuple->rightButton()->setAccessibleName("AddBtn");
     m_buttonTuple->leftButton()->setText(tr("Cancel"));
-    m_buttonTuple->leftButton()->setAccessibleName(tr("Cancel"));
+    m_buttonTuple->leftButton()->setAccessibleName("CancelBtn");
     QHBoxLayout *hlayout4 = new QHBoxLayout(this);
     hlayout4->addSpacing(10);
     hlayout4->addWidget(m_buttonTuple, 0, Qt::AlignBottom);
