@@ -14,7 +14,7 @@
         <translation>Əlavələr</translation>
     </message>
     <message>
-        <location filename="../src/window/advancedsettingwidget.cpp" line="247"/>
+        <location filename="../src/window/advancedsettingwidget.cpp" line="391"/>
         <source>None</source>
         <translation>Heç biri</translation>
     </message>
@@ -22,12 +22,43 @@
 <context>
     <name>FcitxConfigPlugin</name>
     <message>
+        <location filename="../src/fcitxconfigplugin.cpp" line="69"/>
+        <location filename="../src/fcitxconfigplugin.cpp" line="81"/>
         <location filename="../src/fcitxconfigplugin.cpp" line="82"/>
-        <location filename="../src/fcitxconfigplugin.cpp" line="90"/>
+        <location filename="../src/fcitxconfigplugin.cpp" line="83"/>
+        <location filename="../src/fcitxconfigplugin.cpp" line="84"/>
+        <location filename="../src/fcitxconfigplugin.cpp" line="85"/>
+        <location filename="../src/fcitxconfigplugin.cpp" line="109"/>
+        <location filename="../src/fcitxconfigplugin.cpp" line="117"/>
         <source>Input Methods</source>
         <translation>Daxiletmə üsulları</translation>
         <extra-contents_path>/keyboard/Manage Input Methods</extra-contents_path>
     </message>
+    <message>
+        <location filename="../src/fcitxconfigplugin.cpp" line="75"/>
+        <source>Keyboard and Language</source>
+        <translation>Klaviatura və Dil</translation>
+    </message>
+    <message>
+        <location filename="../src/fcitxconfigplugin.cpp" line="82"/>
+        <source>Manage Input Methods</source>
+        <translation>Daxiletmə üsulunun idarə edilməsi</translation>
+    </message>
+    <message>
+        <location filename="../src/fcitxconfigplugin.cpp" line="83"/>
+        <source>Switch input methods</source>
+        <translation>Daxiletmə üsullarını dəyişin</translation>
+    </message>
+    <message>
+        <location filename="../src/fcitxconfigplugin.cpp" line="84"/>
+        <source>Switch to the first input method</source>
+        <translation>İlk daxiletmə üsuluna keçin</translation>
+    </message>
+    <message>
+        <location filename="../src/fcitxconfigplugin.cpp" line="85"/>
+        <source>Advanced Settings</source>
+        <translation>Təkmil ayarlar</translation>
+    </message>
 </context>
 <context>
     <name>FcitxSettingsHead</name>
@@ -35,12 +66,12 @@
         <location filename="../src/widgets/settingshead.cpp" line="51"/>
         <location filename="../src/widgets/settingshead.cpp" line="135"/>
         <source>Edit</source>
-        <translation>Düzəlt</translation>
+        <translation>Düzəliş edin</translation>
     </message>
     <message>
         <location filename="../src/widgets/settingshead.cpp" line="137"/>
         <source>Done</source>
-        <translation>Tamamlandı</translation>
+        <translation>Hazır</translation>
     </message>
 </context>
 <context>
@@ -53,21 +84,19 @@
     <message>
         <location filename="../src/window/imaddwindow.cpp" line="70"/>
         <source>Search</source>
-        <translation>Axtar</translation>
+        <translation>Axtarış</translation>
     </message>
     <message>
-        <location filename="../src/window/imaddwindow.cpp" line="79"/>
+        <location filename="../src/window/imaddwindow.cpp" line="80"/>
         <source>Find more in App Store</source>
         <translation>Tətbiq Mağazasında daha çox tapın</translation>
     </message>
     <message>
-        <location filename="../src/window/imaddwindow.cpp" line="85"/>
         <location filename="../src/window/imaddwindow.cpp" line="86"/>
         <source>Add</source>
-        <translation>Əlavə et</translation>
+        <translation>Əlavə edin</translation>
     </message>
     <message>
-        <location filename="../src/window/imaddwindow.cpp" line="87"/>
         <location filename="../src/window/imaddwindow.cpp" line="88"/>
         <source>Cancel</source>
         <translation>İmtina</translation>
@@ -76,54 +105,63 @@
 <context>
     <name>IMSettingWindow</name>
     <message>
-        <location filename="../src/window/imsettingwindow.cpp" line="116"/>
-        <source>Switch input methods</source>
-        <translation>Daxiletmə üsullarını dəyişin</translation>
+        <location filename="../src/window/imsettingwindow.cpp" line="115"/>
+        <source>Scroll between input methods</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/window/imsettingwindow.cpp" line="121"/>
-        <source>Switch to the first input method</source>
-        <translation>İlk daxiletmə üsuluna keçin</translation>
+        <location filename="../src/window/imsettingwindow.cpp" line="119"/>
+        <source>Switch between the current/first input method</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/window/imsettingwindow.cpp" line="124"/>
-        <location filename="../src/window/imsettingwindow.cpp" line="127"/>
+        <location filename="../src/window/imsettingwindow.cpp" line="122"/>
+        <location filename="../src/window/imsettingwindow.cpp" line="125"/>
         <source>Restore Defaults</source>
-        <translation>Varsayəlanların bərpası</translation>
+        <translation>İlkin vəziyyətinə qaytarmaq</translation>
     </message>
     <message>
-        <location filename="../src/window/imsettingwindow.cpp" line="128"/>
+        <location filename="../src/window/imsettingwindow.cpp" line="129"/>
         <source>Advanced Settings</source>
         <translation>Təkmil ayarlar</translation>
+        <extra-child_page>Manage Input Methods</extra-child_page>
+        <extra-contents_path>/keyboard/Manage Input Methods</extra-contents_path>
     </message>
     <message>
-        <location filename="../src/window/imsettingwindow.cpp" line="138"/>
+        <location filename="../src/window/imsettingwindow.cpp" line="139"/>
         <source>Manage Input Methods</source>
         <translation>Daxiletmə üsulunun idarə edilməsi</translation>
         <extra-child_page>Manage Input Methods</extra-child_page>
         <extra-contents_path>/keyboard/Manage Input Methods</extra-contents_path>
     </message>
     <message>
-        <location filename="../src/window/imsettingwindow.cpp" line="148"/>
+        <location filename="../src/window/imsettingwindow.cpp" line="149"/>
         <source>Shortcuts</source>
         <translation>Qısayollar</translation>
         <extra-child_page>Manage Input Methods</extra-child_page>
         <extra-contents_path>/keyboard/Manage Input Methods</extra-contents_path>
     </message>
+    <message>
+        <location filename="../src/window/imsettingwindow.cpp" line="166"/>
+        <source>Add Input Method</source>
+        <translation>Daxiletmə üsulu əlavə edin</translation>
+        <extra-child_page>Manage Input Methods</extra-child_page>
+        <extra-contents_path>/keyboard/Manage Input Methods</extra-contents_path>
+    </message>
 </context>
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../src/window/advancedsettingwidget.cpp" line="554"/>
-        <location filename="../src/window/advancedsettingwidget.cpp" line="615"/>
+        <location filename="../src/window/advancedsettingwidget.cpp" line="585"/>
+        <location filename="../src/window/advancedsettingwidget.cpp" line="637"/>
         <source>None</source>
-        <translation type="unfinished">Heç biri</translation>
+        <translation>Heç biri</translation>
     </message>
 </context>
 <context>
     <name>dcc_fcitx_configtool::widgets::FcitxCheckBoxSettingsItem</name>
     <message>
-        <location filename="../src/widgets/keysettingsitem.cpp" line="450"/>
+        <location filename="../src/widgets/keysettingsitem.cpp" line="599"/>
         <source>Configure</source>
         <translation>Tənzimləyin</translation>
     </message>
@@ -131,13 +169,13 @@
 <context>
     <name>dcc_fcitx_configtool::widgets::FcitxKeyLabelWidget</name>
     <message>
-        <location filename="../src/widgets/keysettingsitem.cpp" line="46"/>
-        <location filename="../src/widgets/keysettingsitem.cpp" line="165"/>
+        <location filename="../src/widgets/keysettingsitem.cpp" line="47"/>
+        <location filename="../src/widgets/keysettingsitem.cpp" line="166"/>
         <source>None</source>
         <translation>Heç biri</translation>
     </message>
     <message>
-        <location filename="../src/widgets/keysettingsitem.cpp" line="52"/>
+        <location filename="../src/widgets/keysettingsitem.cpp" line="53"/>
         <source>Enter a new shortcut</source>
         <translation>Yeni qısayol daxil edin</translation>
     </message>
