@@ -4,17 +4,17 @@
 <context>
     <name>Fcitx::AdvancedSettingWidget</name>
     <message>
-        <location filename="../src/window/advancedsettingwidget.cpp" line="104"/>
+        <location filename="../src/window/advancedsettingwidget.cpp" line="105"/>
         <source>Global Config</source>
         <translation>Globalne Ustawienia</translation>
     </message>
     <message>
-        <location filename="../src/window/advancedsettingwidget.cpp" line="107"/>
+        <location filename="../src/window/advancedsettingwidget.cpp" line="108"/>
         <source>Add-ons</source>
-        <translation>Dodatki</translation>
+        <translation>Wtyczki</translation>
     </message>
     <message>
-        <location filename="../src/window/advancedsettingwidget.cpp" line="241"/>
+        <location filename="../src/window/advancedsettingwidget.cpp" line="391"/>
         <source>None</source>
         <translation>Brak</translation>
     </message>
@@ -31,7 +31,7 @@
         <location filename="../src/fcitxconfigplugin.cpp" line="109"/>
         <location filename="../src/fcitxconfigplugin.cpp" line="117"/>
         <source>Input Methods</source>
-        <translation>Urządzenia wejścia</translation>
+        <translation>Metody Wprowadzania</translation>
         <extra-contents_path>/keyboard/Manage Input Methods</extra-contents_path>
     </message>
     <message>
@@ -42,22 +42,22 @@
     <message>
         <location filename="../src/fcitxconfigplugin.cpp" line="82"/>
         <source>Manage Input Methods</source>
-        <translation>Zarządzaj urządzeniami wejścia</translation>
+        <translation>Zarządzaj metodami wejścia</translation>
     </message>
     <message>
         <location filename="../src/fcitxconfigplugin.cpp" line="83"/>
         <source>Switch input methods</source>
-        <translation>Zamień urządzenia wejścia</translation>
+        <translation>Przełącz metody wejścia</translation>
     </message>
     <message>
         <location filename="../src/fcitxconfigplugin.cpp" line="84"/>
         <source>Switch to the first input method</source>
-        <translation>Wróć do pierwszego urządzenia wejścia</translation>
+        <translation>Wróć do pierwszej metody wejścia</translation>
     </message>
     <message>
         <location filename="../src/fcitxconfigplugin.cpp" line="85"/>
         <source>Advanced Settings</source>
-        <translation>Zaawansowane ustawienia</translation>
+        <translation>Ustawienia zaawansowane</translation>
     </message>
 </context>
 <context>
@@ -79,7 +79,7 @@
     <message>
         <location filename="../src/window/imaddwindow.cpp" line="62"/>
         <source>Add Input Method</source>
-        <translation>Dodaj urządzenie wejścia</translation>
+        <translation>Dodaj metodę wejścia</translation>
     </message>
     <message>
         <location filename="../src/window/imaddwindow.cpp" line="70"/>
@@ -106,45 +106,45 @@
     <name>IMSettingWindow</name>
     <message>
         <location filename="../src/window/imsettingwindow.cpp" line="115"/>
-        <source>Switch input methods</source>
-        <translation>Zamień urządzenia wejścia</translation>
+        <source>Scroll between input methods</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../src/window/imsettingwindow.cpp" line="119"/>
-        <source>Switch to the first input method</source>
-        <translation>Wróć do pierwszego urządzenia wejścia</translation>
+        <source>Switch between the current/first input method</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/window/imsettingwindow.cpp" line="121"/>
-        <location filename="../src/window/imsettingwindow.cpp" line="124"/>
+        <location filename="../src/window/imsettingwindow.cpp" line="122"/>
+        <location filename="../src/window/imsettingwindow.cpp" line="125"/>
         <source>Restore Defaults</source>
         <translation>Przywróć domyślne</translation>
     </message>
     <message>
-        <location filename="../src/window/imsettingwindow.cpp" line="128"/>
+        <location filename="../src/window/imsettingwindow.cpp" line="129"/>
         <source>Advanced Settings</source>
-        <translation>Zaawansowane ustawienia</translation>
+        <translation>Ustawienia zaawansowane</translation>
         <extra-child_page>Manage Input Methods</extra-child_page>
         <extra-contents_path>/keyboard/Manage Input Methods</extra-contents_path>
     </message>
     <message>
-        <location filename="../src/window/imsettingwindow.cpp" line="138"/>
+        <location filename="../src/window/imsettingwindow.cpp" line="139"/>
         <source>Manage Input Methods</source>
-        <translation>Zarządzaj urządzeniami wejścia</translation>
+        <translation>Zarządzaj metodami wejścia</translation>
         <extra-child_page>Manage Input Methods</extra-child_page>
         <extra-contents_path>/keyboard/Manage Input Methods</extra-contents_path>
     </message>
     <message>
-        <location filename="../src/window/imsettingwindow.cpp" line="148"/>
+        <location filename="../src/window/imsettingwindow.cpp" line="149"/>
         <source>Shortcuts</source>
         <translation>Skróty</translation>
         <extra-child_page>Manage Input Methods</extra-child_page>
         <extra-contents_path>/keyboard/Manage Input Methods</extra-contents_path>
     </message>
     <message>
-        <location filename="../src/window/imsettingwindow.cpp" line="165"/>
+        <location filename="../src/window/imsettingwindow.cpp" line="166"/>
         <source>Add Input Method</source>
-        <translation type="unfinished">Dodaj urządzenie wejścia</translation>
+        <translation>Dodaj metodę wejścia</translation>
         <extra-child_page>Manage Input Methods</extra-child_page>
         <extra-contents_path>/keyboard/Manage Input Methods</extra-contents_path>
     </message>
@@ -152,8 +152,8 @@
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../src/window/advancedsettingwidget.cpp" line="606"/>
-        <location filename="../src/window/advancedsettingwidget.cpp" line="658"/>
+        <location filename="../src/window/advancedsettingwidget.cpp" line="585"/>
+        <location filename="../src/window/advancedsettingwidget.cpp" line="637"/>
         <source>None</source>
         <translation>Brak</translation>
     </message>
@@ -161,7 +161,7 @@
 <context>
     <name>dcc_fcitx_configtool::widgets::FcitxCheckBoxSettingsItem</name>
     <message>
-        <location filename="../src/widgets/keysettingsitem.cpp" line="596"/>
+        <location filename="../src/widgets/keysettingsitem.cpp" line="599"/>
         <source>Configure</source>
         <translation>Skonfiguruj</translation>
     </message>
